﻿/*
 * Chronometre.cpp
 * This file is part of ChronoCheckMate
 *
 * Copyright (C) 2010 - François Drouhard
 *
 * ChronoCheckMate is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * ChronoCheckMate is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ChronoCheckMate; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 */
 
#include "Chronometre.h"
#include <QTimer>
#include <QtWidgets>
#include <QLabel>
#include <QObject>
#include <QHBoxLayout>
#include <QDebug>
#include <QFont>
#include <QTime>

Chronometre::Chronometre (const QString & nom , QTime const& tempsDepart, QWidget * parent = nullptr) :
    QGroupBox (nom , parent),
    temps(tempsDepart),
    msTempsDepart(tempsDepart)
{
    setFlat(false);

    QFont font("Arial" , 22 , 5);

    ecranTemps = new QLabel(temps.toString("hh:mm:ss:zzz"));
    ecranTemps->setFont(font);

    ecranLayout = new QHBoxLayout;
    ecranLayout->addSpacing(40);
    ecranLayout->addWidget(ecranTemps);
    ecranLayout->addSpacing(40);

    setLayout (ecranLayout);
	
    timer = new QTimer  (this);
    timer->setInterval (INTERVAL);
	QObject::connect (timer , SIGNAL (timeout() ) , this , SLOT (refresh()));
}

void Chronometre::modifierNomJoueur(QString joueur) {
    setTitle(joueur);
}

void Chronometre::definirTemps(QTime const& tempsDepart) {
    msTempsDepart = tempsDepart;
}

void Chronometre::refresh () {
    temps = temps.addMSecs(-INTERVAL);
    affichage ();
    if (temps <= QTime (0,0,0,0)) {
        emit fin();
    }
}

void Chronometre::start () {
	timer->start ();
}

void Chronometre::stop () {
    timer->stop();
}


void Chronometre::affichage () {
    QString chaineTemps = temps.toString("hh:mm:ss:zzz");
    ecranTemps->setText(chaineTemps);
}

void Chronometre::reinit () {
	if (timer->isActive()) {
		timer->stop();
	}
    temps  = msTempsDepart;
	affichage();
}

void Chronometre::basculer () {
	if (timer->isActive()) {
        stop();
	}
	else {
        start ();
	}
}

QString Chronometre::operator+=(Chronometre const& joueur) const {
    if (temps <= QTime (0,0,0,0)) {
        return joueur.title();
    } else if (joueur.temps <= QTime(0,0,0,0)) {
        return title();
    }
    return "Nope";
}
